vsutillib.scripts package
=========================

Small command line set of utilities.

The ``mkvrun`` script
---------------------

.. autofunction:: vsutillib.scripts.mkvrun

The ``apply2files`` script
--------------------------

.. autofunction:: vsutillib.scripts.apply2files
